@@ -1,4 +1,5 @@
-use crate::linux::{detect_linux_ping, LinuxPingType, PingDetectionError};
+#[cfg(unix)]
+use crate::linux::{detect_linux_ping, LinuxPingType};
 /// Pinger
 /// This crate exposes a simple function to ping remote hosts across different operating systems.
 /// Example:
@@ -33,6 +34,7 @@ pub mod macos;
 #[cfg(windows)]
 pub mod windows;
 
+mod bsd;
 #[cfg(test)]
 mod test;
 
@@ -131,6 +133,20 @@ impl fmt::Display for PingResult {
     }
 }
 
+#[derive(Error, Debug)]
+pub enum PingDetectionError {
+    #[error("Could not detect ping. Stderr: {stderr:?}\nStdout: {stdout:?}")]
+    UnknownPing {
+        stderr: Vec<String>,
+        stdout: Vec<String>,
+    },
+    #[error(transparent)]
+    CommandError(#[from] anyhow::Error),
+
+    #[error("Installed ping is not supported: {alternative}")]
+    NotSupported { alternative: String },
+}
+
 #[derive(Error, Debug)]
 pub enum PingError {
     #[error("Could not detect ping command type")]
@@ -154,7 +170,15 @@ pub fn ping_with_interval(addr: String, interval: Duration) -> Result<mpsc::Rece
     }
     #[cfg(unix)]
     {
-        if cfg!(target_os = "macos") {
+        if cfg!(target_os = "freebsd")
+            || cfg!(target_os = "dragonfly")
+            || cfg!(target_os = "openbsd")
+            || cfg!(target_os = "netbsd")
+        {
+            let mut p = bsd::BSDPinger::default();
+            p.set_interval(interval);
+            p.start::<bsd::BSDParser>(addr)
+        } else if cfg!(target_os = "macos") {
             let mut p = macos::MacOSPinger::default();
             p.set_interval(interval);
             p.start::<macos::MacOSParser>(addr)
