@@ -1,8 +1,7 @@
-use crate::{run_ping, Parser, PingResult, Pinger};
+use crate::{run_ping, Parser, PingDetectionError, PingResult, Pinger};
 use anyhow::Context;
 use regex::Regex;
 use std::time::Duration;
-use thiserror::Error;
 
 #[derive(Debug, Eq, PartialEq)]
 pub enum LinuxPingType {
@@ -10,20 +9,6 @@ pub enum LinuxPingType {
     IPTools,
 }
 
-#[derive(Error, Debug)]
-pub enum PingDetectionError {
-    #[error("Could not detect ping. Stderr: {stderr:?}\nStdout: {stdout:?}")]
-    UnknownPing {
-        stderr: Vec<String>,
-        stdout: Vec<String>,
-    },
-    #[error(transparent)]
-    CommandError(#[from] anyhow::Error),
-
-    #[error("Installed ping is not supported: {alternative}")]
-    NotSupported { alternative: String },
-}
-
 pub fn detect_linux_ping() -> Result<LinuxPingType, PingDetectionError> {
     // Err(PingDetectionError::Thing)
     let child = run_ping(vec!["-V".to_string()], true);
